@@ -47,11 +47,12 @@ class Processor(object):
                 task()
                 self.application.ioloop.add_timeout(self.application.interval, self.next)
             else:
-                self.process = subprocess.Popen(task, shell=True, stdout=subprocess.PIPE)
+                self.process = subprocess.Popen(task)
                 self.application.ioloop.add_timeout(self.application.interval, self.wait)
 
     def wait(self):
         return_code = self.process.returncode
+        print "wait", return_code
         if return_code is None:
             self.application.ioloop.add_timeout(self.application.interval, self.wait)
         elif return_code == 0:
